@@ -22,56 +22,56 @@
 #define HEIGHT (currentfont->height)
 #define DATA currentfont->data
 
-extern CONST unsigned char xfont8[];
-extern CONST unsigned char xfont16[];
-extern CONST unsigned char xfont32[];
-extern CONST unsigned char xfont48[];
-extern CONST unsigned char xfont14[];
-extern CONST unsigned char xfont8il1[];
-extern CONST unsigned char xfont16il1[];
-extern CONST unsigned char xfont14il1[];
+extern const unsigned char xfont8[];
+extern const unsigned char xfont16[];
+extern const unsigned char xfont32[];
+extern const unsigned char xfont48[];
+extern const unsigned char xfont14[];
+extern const unsigned char xfont8il1[];
+extern const unsigned char xfont16il1[];
+extern const unsigned char xfont14il1[];
 unsigned char *aa_chardata;
 unsigned char *aa_colordata;
 int aa_cursorx, aa_cursory;
-static CONST struct xfont *currentfont;
-CONST struct xfont xaafont = {
+static const struct xfont *currentfont;
+const struct xfont xaafont = {
     NULL,
-    2, 1, 2
+    2, 1, 2, 2
 };
 
-CONST struct xfont xsmallfont = {
+const struct xfont xsmallfont = {
     xfont14,
-    8, 14, 8
+    8, 14, 8, 2
 };
 
-CONST struct xfont xbigfont = {
+const struct xfont xbigfont = {
     xfont16,
-    9, 16, 8
+    9, 16, 8, 2
 };
 
-CONST struct xfont xbigfont2 = {
+const struct xfont xbigfont2 = {
     xfont32,
-    18, 32, 16
+    18, 32, 16, 2
 };
 
-CONST struct xfont xbigfont3 = {
+const struct xfont xbigfont3 = {
     xfont48,
-    18, 48, 16
+    18, 48, 16, 2
 };
 
-CONST struct xfont xsmallfontil1 = {
+const struct xfont xsmallfontil1 = {
     xfont8il1,
-    8, 8, 8
+    8, 8, 8, 1
 };
 
-CONST struct xfont xmedfontil1 = {
+const struct xfont xmedfontil1 = {
     xfont14il1,
-    8, 14, 8
+    8, 14, 8, 1
 };
 
-CONST struct xfont xbigfontil1 = {
+const struct xfont xbigfontil1 = {
     xfont16il1,
-    9, 16, 8
+    9, 16, 8, 1
 };
 
 #include <c256.h>
@@ -119,12 +119,12 @@ CONST struct xfont xbigfontil1 = {
 #define restoreline restoreline32
 #include "grlibd.c"
 #ifdef SBITMAPS
-static inline void
+static INLINE void
 drawchar1(struct image *img, int x, int y, int fgcolor,
 	  unsigned char letter)
 {
     int fontwidth = (RWIDTH(letter) + 7) / 8;
-    CONST unsigned char *bitmap = &DATA[letter * HEIGHT * fontwidth];
+    const unsigned char *bitmap = &DATA[letter * HEIGHT * fontwidth];
     unsigned char *current;
     int yend = y + HEIGHT;
     if (y < 0)
@@ -220,7 +220,7 @@ static void vline1(struct image *img, int x, int y, int l, int color)
     }
 }
 
-static inline void
+static INLINE void
 rectangle1(struct image *img, int x, int y, int width, int height,
 	   int fgcolor)
 {
@@ -229,7 +229,7 @@ rectangle1(struct image *img, int x, int y, int width, int height,
 	hline1(img, x, y, width - 1, fgcolor), y++;
 }
 
-static inline void
+static INLINE void
 line1(struct image *img, int x, int y, int x2, int y2, int color)
 {
     int dx = x2 - x;
@@ -355,7 +355,7 @@ line1(struct image *img, int x, int y, int x2, int y2, int color)
 }
 #endif
 
-static int skip(CONST char *text)
+static int skip(const char *text)
 {
     int i = 0;
     while (*text && *text != '\n')
@@ -364,7 +364,7 @@ static int skip(CONST char *text)
 }
 
 #ifdef HAVE_GETTEXT
-int
+static int
 xiconv(int encoding, char *out, int *outlen, const char *in, int *inlen)
 {
     /* 
@@ -410,22 +410,29 @@ xiconv(int encoding, char *out, int *outlen, const char *in, int *inlen)
 }
 #endif
 
+//#ifndef PLATFORM_TEXT_RENDERING
+
 int
-xprint(struct image *image, CONST struct xfont *current, int x, int y,
-       CONST char *text, int encoding, int fgcolor, int bgcolor, int mode)
+xprint(struct image *image, const struct xfont *current, int x, int y,
+       const char *text, int fgcolor, int bgcolor, int mode)
 {
     int i = 0;
     int aacolor = 0;
-#ifdef HAVE_GETTEXT
     char intext[BUFSIZ];
-    int inlen = strlen(text);
-    char outtext[BUFSIZ];
-    int outlen = BUFSIZ;
-
     strncpy(intext, text, BUFSIZ);
-    if (encoding
-	&& xiconv(encoding, outtext, &outlen, intext, &inlen) == 0)
-	text = outtext;
+
+    if (image->driver && image->driver->print)
+        return image->driver->print(image, x, y, text, fgcolor, bgcolor, mode);
+
+#ifdef HAVE_GETTEXT
+    {
+        int inlen = strlen(text);
+        char outtext[BUFSIZ];
+        int outlen = BUFSIZ;
+        if (current->encoding
+            && xiconv(current->encoding, outtext, &outlen, intext, &inlen) == 0)
+            text = outtext;
+    }
 #endif
     if (!text[0])
 	return 0;
@@ -507,18 +514,59 @@ xprint(struct image *image, CONST struct xfont *current, int x, int y,
 	text++;
 	i++;
     }
-    return i + skip(text);
+    /*
+     * We need to return the number of bytes used from the string that is 
+     * passed into the function; not the number of characters displayed.  The
+     * number of bytes and the number of characters is not always the same in
+     * UTF-8 encoding.  So I changed this to count the number of bytes to 
+     * the next newline or nul in the original string that was passed in.
+     */
+    /* return i + skip(text); */
+    return skip(intext); 
 }
 
-int xtextwidth(CONST struct xfont *font, CONST char *text)
+int xtextwidth(struct image *image, const struct xfont *font, const char *text)
 {
     int i;
+
+    if (image->driver && image->driver->textwidth)
+        return image->driver->textwidth(image, text);
+
+#ifdef HAVE_GETTEXT
+    char intext[BUFSIZ];
+    int inlen = strlen(text);
+    char outtext[BUFSIZ];
+    int outlen = BUFSIZ;
+    
+    strncpy(intext, text, BUFSIZ);
+    if (font->encoding
+	&& xiconv(font->encoding, outtext, &outlen, intext, &inlen) == 0)
+	text = outtext;
+#endif
     for (i = 0; text[i] && text[i] != '\n'; i++);
     if (font->width == 2)
 	return (i * font->width);
     return (i * font->width + 1);
 }
 
+int xtextheight(struct image *image, const struct xfont *font)
+{
+    if (image->driver && image->driver->textheight)
+        return image->driver->textheight(image);
+
+    return font->height+1;
+}
+
+int xtextcharw(struct image *image, const struct xfont *font, const char c)
+{
+    if (image->driver && image->driver->charwidth)
+        return image->driver->charwidth(image, c);
+
+    return font->width;
+}
+
+//#endif /* PLATFORM_TEXT_RENDERING */
+
 void xhline(struct image *image, int x, int y, int width, int fgcolor)
 {
     /*Do some clipping */
@@ -642,7 +690,7 @@ xrectangle(struct image *image, int x, int y, int width, int height,
     }
 }
 
-static inline char *savehline(struct image *i, int x1, int y, int x2)
+static INLINE char *savehline(struct image *i, int x1, int y, int x2)
 {
     int start, end;
     char *c;
@@ -657,7 +705,7 @@ static inline char *savehline(struct image *i, int x1, int y, int x2)
     return c;
 }
 
-static inline void
+static INLINE void
 restorehline(struct image *i, char *c, int x1, int y, int x2)
 {
     int start, end;
@@ -672,7 +720,7 @@ restorehline(struct image *i, char *c, int x1, int y, int x2)
 #define  __clipy1 0
 #define  __clipx2 (img->width-2)
 #define  __clipy2 (img->height-2)
-static inline int regioncode(struct image *img, const int x, const int y)
+static INLINE int regioncode(struct image *img, const int x, const int y)
 {
     int dx1, dx2, dy1, dy2;
     int result;
