@@ -58,7 +58,7 @@
 
 struct dialogitem;
 struct dialogtype {
-    void (*build) (struct dialogitem * item, CONST menudialog * entry);
+    void (*build) (struct dialogitem * item, const menudialog * entry);
     int (*key) (struct dialogitem * item, int key);
     void (*mouse) (struct dialogitem * item, int x, int y, int buttons,
 		   int flags);
@@ -69,25 +69,25 @@ struct dialogtype {
 struct dialogitem {
     int y;
     int width, width1, height;
-    CONST menudialog *dialog;
+    const menudialog *dialog;
     void *data;
-    CONST struct dialogtype *type;
+    const struct dialogtype *type;
 };
 static struct opendialog {
     int x, y, width, height;
     int half;
     int nitems;
-    CONST menudialog *dialog;
+    const menudialog *dialog;
     int mousereleased;
     int mousegrab;
-    CONST menuitem *item;
+    const menuitem *item;
     int current;
     struct dialogitem *items;
     struct uih_window *window;
 } dialog;
 
 static dialogparam *qparam;
-static CONST menuitem *qitem;
+static const menuitem *qitem;
 
 int dialogvisible;
 
@@ -104,9 +104,9 @@ static struct yesnodialog {
 } yesnodialog;
 
 // These 3 definitions are no longer used:
-static CONST char *CONST oktext = "OK";
-static CONST char *CONST canceltext = "Cancel";
-static CONST char *CONST helptext = "Help";
+static const char *const oktext = "OK";
+static const char *const canceltext = "Cancel";
+static const char *const helptext = "Help";
 
 static int okwidth;
 static int cancelwidth;
@@ -133,30 +133,30 @@ struct okdata {
     int selected;
 };
 
-CONST char *CONST yestext = "Yes";
-CONST char *CONST notext = "No";
+const char *const yestext = "Yes";
+const char *const notext = "No";
 #define YESNOX ((uih->image->width-yesnodialog.width)/2)
 #define YESNOHEIGHT (2*BUTTONHEIGHT+2*BORDERHEIGHT)
 #define YESNOY ((uih->image->height-YESNOHEIGHT)/2)
 void
-ui_drawbutton(CONST char *text, int pressed, int selected, int x1, int x2,
+ui_drawbutton(const char *text, int pressed, int selected, int x1, int x2,
 	      int y)
 {
-    int width = xtextwidth(uih->font, text);
+    int width = xtextwidth(uih->image, uih->font, text);
     /*printf("%s %i %i\n",text,pressed,selected); */
     if (uih->palette->type & BITMAPS) {
 	uih_drawborder(uih, x1, y, x2 - x1, BUTTONHEIGHT,
 		       (pressed != 0
 			|| selected != 0) * BORDER_PRESSED | BORDER_LIGHT);
 	xprint(uih->image, uih->font, (x1 + x2 - width) / 2 + pressed,
-	       y + BORDERHEIGHT + pressed, text, uih->encoding, selected
+	       y + BORDERHEIGHT + pressed, text, selected
 	       || pressed ? BGCOLOR(uih) : FGCOLOR(uih), BGCOLOR(uih),
 	       TEXT_PRESSED);
     } else {
 	uih_drawborder(uih, x1, y, x2 - x1, BUTTONHEIGHT,
 		       (pressed != 0) * BORDER_PRESSED | BORDER_LIGHT);
 	xprint(uih->image, uih->font, (x1 + x2 - width) / 2 + pressed,
-	       y + BORDERHEIGHT + pressed, text, uih->encoding,
+	       y + BORDERHEIGHT + pressed, text, 
 	       selected ? SELCOLOR(uih) : FGCOLOR(uih), BGCOLOR(uih),
 	       /*TEXT_PRESSED */ 0);
     }
@@ -183,7 +183,7 @@ static void ui_drawyesno(struct uih_context *c, void *data)
 {
     xprint(uih->image, uih->font,
 	   YESNOX + (yesnodialog.width - yesnodialog.questionwidth) / 2,
-	   YESNOY + BORDERHEIGHT, yesnodialog.question, uih->encoding,
+	   YESNOY + BORDERHEIGHT, yesnodialog.question, 
 	   FGCOLOR(uih), BGCOLOR(uih), 0);
     ui_drawbutton(yestext, yesnodialog.pressed == 0,
 		  yesnodialog.selected == 0, YESNOX + BORDERWIDTH + 1,
@@ -207,16 +207,16 @@ static void ui_closeyesno(int success)
     uih->display = 1;
 }
 
-void ui_buildyesno(CONST char *question, void (*handler) (int yes))
+void ui_buildyesno(const char *question, void (*handler) (int yes))
 {
     if (yesnodialogvisible)
 	ui_closeyesno(0);
     yesnodialogvisible = 1;
-    yesnodialog.questionwidth = xtextwidth(uih->font, question);
+    yesnodialog.questionwidth = xtextwidth(uih->image, uih->font, question);
     yesnodialog.question = mystrdup(question);
     yesnodialog.mousereleased = 0;
     yesnodialog.width =
-	xtextwidth(uih->font, yestext) + xtextwidth(uih->font,
+	xtextwidth(uih->image, uih->font, yestext) + xtextwidth(uih->image, uih->font,
 						    notext) +
 	8 * BORDERWIDTH + 2;
     if (yesnodialog.width < yesnodialog.questionwidth)
@@ -305,12 +305,12 @@ static int ui_mouseyesno(int x, int y, int buttons, int flags)
     return 1;
 }
 
-static void ui_buildok(struct dialogitem *item, CONST menudialog * entry)
+static void ui_buildok(struct dialogitem *item, const menudialog * entry)
 {
     struct okdata *ok;
     item->height = BUTTONHEIGHT;
-    okwidth = xtextwidth(uih->font, gettext("OK"));
-    cancelwidth = xtextwidth(uih->font, gettext("Cancel"));
+    okwidth = xtextwidth(uih->image, uih->font, gettext("OK"));
+    cancelwidth = xtextwidth(uih->image, uih->font, gettext("Cancel"));
     item->width = okwidth + 2 * BORDERWIDTH + 2;
     item->width1 = cancelwidth + 2 * BORDERWIDTH + 2;
     if (item->width < item->width1)
@@ -414,7 +414,7 @@ static void ui_unselectok(struct dialogitem *item)
     uih->display = 1;
 }
 
-CONST static struct dialogtype okdialog = {
+const static struct dialogtype okdialog = {
     ui_buildok,
     ui_keyok,
     ui_mouseok,
@@ -440,7 +440,7 @@ void ui_updatetext(struct ui_textdata *d)
 	for (i = 0; d->text[d->start + i]; i++) {
 	    if (d->start + i == d->cursor)
 		d->cursorpos = wi;
-	    wi += xtextcharw(uih->font, d->taxt[d->start + i]);
+	    wi += xtextcharw(uih->image, uih->font, d->text[d->start + i]);
 	    if (wi >= d->width) {
 		break;
 	    }
@@ -457,7 +457,7 @@ void ui_updatetext(struct ui_textdata *d)
     while (again);
 }
 
-struct ui_textdata *ui_opentext(int x, int y, int width, CONST char *def)
+struct ui_textdata *ui_opentext(int x, int y, int width, const char *def)
 {
     struct ui_textdata *d = (struct ui_textdata *) malloc(sizeof(*d));
     char *text;
@@ -485,7 +485,7 @@ void ui_drawtext(struct ui_textdata *d, int active)
     char *c = (char *) malloc(d->ndisplayed + 2);
     strncpy(c, d->text + d->start, d->ndisplayed);
     c[d->ndisplayed] = 0;
-    xprint(uih->image, uih->font, d->x, d->y, c, uih->encoding,
+    xprint(uih->image, uih->font, d->x, d->y, c, 
 	   (uih->palette->type & BITMAPS) ? BGCOLOR(uih) : ((active
 							     && d->clear) ?
 							    SELCOLOR(uih) :
@@ -496,19 +496,19 @@ void ui_drawtext(struct ui_textdata *d, int active)
 	xdrawcursor(uih->image, d->x + d->cursorpos, d->y,
 		    (uih->palette->
 		     type & BITMAPS) ? BGCOLOR(uih) : SELCOLOR(uih),
-		    xtextheight(uih->font));
+		    xtextheight(uih->image, uih->font));
     }
     free(c);
 }
 
 void ui_textmouse(struct ui_textdata *d, int x, int y)
 {
-    if (y > d->y && y < d->y + xtextheight(uih->font) && x > d->x) {
+    if (y > d->y && y < d->y + xtextheight(uih->image, uih->font) && x > d->x) {
 	int w = 0;
 	int i;
 	int xp = d->x;
 	for (i = 0; i < d->ndisplayed + 1 && xp - w / 2 < x; i++) {
-	    w = xtextcharw(uih->font, d->text[i + d->start]);
+	    w = xtextcharw(uih->image, uih->font, d->text[i + d->start]);
 	    xp += w;
 	}
 	d->cursor = i + d->start - 1;
@@ -599,11 +599,11 @@ int ui_textkey(struct ui_textdata *d, int key)
 }
 
 static void
-ui_buildstring(struct dialogitem *item, CONST menudialog * entry)
+ui_buildstring(struct dialogitem *item, const menudialog * entry)
 {
     item->height = BUTTONHEIGHT;
-    item->width = xtextwidth(uih->font, item->dialog->question);
-    item->width1 = xtextcharw(uih->font, 'w') * 20;
+    item->width = xtextwidth(uih->image, uih->font, item->dialog->question);
+    item->width1 = xtextcharw(uih->image, uih->font, 'w') * 20;
     item->data = ui_opentext(0, 0, 2043, item->dialog->defstr);
 }
 
@@ -623,12 +623,11 @@ static void ui_drawquestion(struct dialogitem *item)
 		       BUTTONHEIGHT, FGCOLOR(uih));
 	xprint(uih->image, uih->font, dialog.half - item->width,
 	       item->y + BORDERHEIGHT, item->dialog->question,
-	       uih->encoding, SELECTED(item) ? BGCOLOR(uih) : FGCOLOR(uih),
+	       SELECTED(item) ? BGCOLOR(uih) : FGCOLOR(uih),
 	       BGCOLOR(uih), TEXT_PRESSED);
     } else {
 	xprint(uih->image, uih->font, dialog.half - item->width,
 	       item->y + BORDERHEIGHT, item->dialog->question,
-	       uih->encoding,
 	       SELECTED(item) ? SELCOLOR(uih) : FGCOLOR(uih), BGCOLOR(uih),
 	       0);
     }
@@ -668,7 +667,7 @@ static void ui_unselectstring(struct dialogitem *item)
 {
 }
 
-CONST static struct dialogtype stringdialog = {
+const static struct dialogtype stringdialog = {
     ui_buildstring,
     ui_keystring,
     ui_mousestring,
@@ -677,12 +676,12 @@ CONST static struct dialogtype stringdialog = {
     ui_unselectstring
 };
 
-static void ui_buildint(struct dialogitem *item, CONST menudialog * entry)
+static void ui_buildint(struct dialogitem *item, const menudialog * entry)
 {
     char s[50];
     item->height = BUTTONHEIGHT;
-    item->width = xtextwidth(uih->font, item->dialog->question);
-    item->width1 = xtextcharw(uih->font, 'w') * 5;
+    item->width = xtextwidth(uih->image, uih->font, item->dialog->question);
+    item->width1 = xtextcharw(uih->image, uih->font, 'w') * 5;
     sprintf(s, "%i", item->dialog->defint);
     item->data = ui_opentext(0, 0, 2043, s);
 }
@@ -694,7 +693,7 @@ static void ui_destroyint(struct dialogitem *item, dialogparam * param)
     ui_closetext(text);
 }
 
-CONST static struct dialogtype intdialog = {
+const static struct dialogtype intdialog = {
     ui_buildint,
     ui_keystring,
     ui_mousestring,
@@ -703,7 +702,7 @@ CONST static struct dialogtype intdialog = {
     ui_unselectstring
 };
 
-static CONST char *ui_getextension(CONST char *ch)
+static const char *ui_getextension(const char *ch)
 {
     int i = 0;
     while (ch[i]) {
@@ -714,7 +713,7 @@ static CONST char *ui_getextension(CONST char *ch)
     return ch + i;
 }
 
-number_t ui_getfloat(CONST char *c)
+number_t ui_getfloat(const char *c)
 {
 #ifdef HAVE_LONG_DOUBLE
     long double param;
@@ -742,7 +741,7 @@ number_t ui_getfloat(CONST char *c)
     return (param);
 }
 
-#define BROWSEWIDTH /*(2*BORDERWIDTH+xtextcharw(uih->font,'B'))*/BUTTONHEIGHT
+#define BROWSEWIDTH /*(2*BORDERWIDTH+xtextcharw(uih->image, uih->font,'B'))*/BUTTONHEIGHT
 struct ui_filedata {
     struct ui_textdata *text;
     int active;
@@ -750,7 +749,7 @@ struct ui_filedata {
 };
 
 static struct dialogitem *curritem;
-static void filecallback(CONST char *name, int succ)
+static void filecallback(const char *name, int succ)
 {
     struct ui_filedata *text = (struct ui_filedata *) curritem->data;
     if (succ) {
@@ -763,15 +762,15 @@ static void filecallback(CONST char *name, int succ)
 	ui_closedialog(succ);
 }
 
-static void ui_buildfile(struct dialogitem *item, CONST menudialog * entry)
+static void ui_buildfile(struct dialogitem *item, const menudialog * entry)
 {
     char str[256];
     struct ui_filedata *data =
 	(struct ui_filedata *) malloc(sizeof(*data));
     int i = 0;
     item->height = BUTTONHEIGHT;
-    item->width = xtextwidth(uih->font, item->dialog->question);
-    item->width1 = xtextcharw(uih->font, 'w') * 20;
+    item->width = xtextwidth(uih->image, uih->font, item->dialog->question);
+    item->width1 = xtextcharw(uih->image, uih->font, 'w') * 20;
     while (item->dialog->defstr[i] != '*' && item->dialog->defstr[i] != 0)
 	str[i] = item->dialog->defstr[i], i++;
     str[i] = 0;
@@ -820,7 +819,7 @@ static void ui_drawfile(struct dialogitem *item)
 		   BUTTONHEIGHT, BORDER_PRESSED | BORDER_LIGHT);
     ui_drawtext(data->text, SELECTED(item) && !data->active);
     xprint(uih->image, uih->font, dialog.half - item->width,
-	   item->y + BORDERHEIGHT, item->dialog->question, uih->encoding,
+	   item->y + BORDERHEIGHT, item->dialog->question,
 	   SELECTED(item) ? SELCOLOR(uih) : FGCOLOR(uih), BGCOLOR(uih), 0);
     ui_drawquestion(item);
     ui_drawbutton("B", data->pressed && SELECTED(item), SELECTED(item)
@@ -907,7 +906,7 @@ static void ui_unselectfile(struct dialogitem *item)
 	text->pressed = 0, uih->display = 1;
 }
 
-CONST static struct dialogtype filedialog = {
+const static struct dialogtype filedialog = {
     ui_buildfile,
     ui_keyfile,
     ui_mousefile,
@@ -917,12 +916,12 @@ CONST static struct dialogtype filedialog = {
 };
 
 static void
-ui_buildfloat(struct dialogitem *item, CONST menudialog * entry)
+ui_buildfloat(struct dialogitem *item, const menudialog * entry)
 {
     char s[50];
     item->height = BUTTONHEIGHT;
-    item->width = xtextwidth(uih->font, item->dialog->question);
-    item->width1 = xtextcharw(uih->font, 'w') * 10;
+    item->width = xtextwidth(uih->image, uih->font, item->dialog->question);
+    item->width1 = xtextcharw(uih->image, uih->font, 'w') * 10;
     sprintf(s, "%g", (double) item->dialog->deffloat);
     item->data = ui_opentext(0, 0, 2043, s);
 }
@@ -934,7 +933,7 @@ static void ui_destroyfloat(struct dialogitem *item, dialogparam * param)
     ui_closetext(text);
 }
 
-CONST static struct dialogtype floatdialog = {
+const static struct dialogtype floatdialog = {
     ui_buildfloat,
     ui_keystring,
     ui_mousestring,
@@ -948,14 +947,14 @@ struct ui_coorddata {
     int active;
 };
 static void
-ui_buildcoord(struct dialogitem *item, CONST menudialog * entry)
+ui_buildcoord(struct dialogitem *item, const menudialog * entry)
 {
     char s[50];
     struct ui_coorddata *data =
 	(struct ui_coorddata *) malloc(sizeof(*data));
     item->height = BUTTONHEIGHT;
-    item->width = xtextwidth(uih->font, item->dialog->question);
-    item->width1 = xtextcharw(uih->font, 'w') * 20;
+    item->width = xtextwidth(uih->image, uih->font, item->dialog->question);
+    item->width1 = xtextcharw(uih->image, uih->font, 'w') * 20;
     item->data = data;
     data->active = 0;
     sprintf(s, "%g", (double) item->dialog->deffloat);
@@ -974,8 +973,8 @@ static void ui_destroycoord(struct dialogitem *item, dialogparam * param)
     free(data);
 }
 
-#define SPACESIZE xtextwidth(uih->font,"+")
-#define ENDSIZE xtextwidth(uih->font,"i")
+#define SPACESIZE xtextwidth(uih->image, uih->font,"+")
+#define ENDSIZE xtextwidth(uih->image, uih->font,"i")
 static void ui_drawcoord(struct dialogitem *item)
 {
     struct ui_coorddata *data = (struct ui_coorddata *) item->data;
@@ -999,11 +998,11 @@ static void ui_drawcoord(struct dialogitem *item)
     ui_drawtext(data->text[0], SELECTED(item) && !data->active);
     ui_drawtext(data->text[1], SELECTED(item) && data->active);
     xprint(uih->image, uih->font, dialog.half + half,
-	   item->y + BORDERHEIGHT, "+", uih->encoding, FGCOLOR(uih),
+	   item->y + BORDERHEIGHT, "+", FGCOLOR(uih),
 	   BGCOLOR(uih), 0);
     xprint(uih->image, uih->font,
 	   dialog.x + dialog.width - BORDERWIDTH - ENDSIZE,
-	   item->y + BORDERHEIGHT, "i", uih->encoding, FGCOLOR(uih),
+	   item->y + BORDERHEIGHT, "i", FGCOLOR(uih),
 	   BGCOLOR(uih), 0);
     ui_drawquestion(item);
 }
@@ -1070,7 +1069,7 @@ static void ui_unselectcoord(struct dialogitem *item)
     text->active = 0;
 }
 
-CONST static struct dialogtype coorddialog = {
+const static struct dialogtype coorddialog = {
     ui_buildcoord,
     ui_keycoord,
     ui_mousecoord,
@@ -1080,7 +1079,7 @@ CONST static struct dialogtype coorddialog = {
 };
 
 struct ui_choicedata {
-    CONST char **texts;
+    const char **texts;
     int selected;
     int n;
 
@@ -1109,8 +1108,8 @@ static void ui_drawchoicemenu(uih_context * uih, void *data)
     int i;
     for (i = 0; i < choice->n; i++) {
 	xprint(uih->image, uih->font, choice->x + BORDERWIDTH,
-	       choice->y + BORDERHEIGHT + i * xtextheight(uih->font),
-	       choice->texts[i], uih->encoding,
+	       choice->y + BORDERHEIGHT + i * xtextheight(uih->image, uih->font),
+	       choice->texts[i],
 	       i == choice->active ? SELCOLOR(uih) : FGCOLOR(uih),
 	       BGCOLOR(uih), 0);
     }
@@ -1124,9 +1123,9 @@ ui_buildchoicemenu(struct uih_context *uih, struct ui_choicedata *choice,
 	return;
     choice->width = width + 2 * BORDERWIDTH;
     choice->x = x;
-    choice->height = xtextheight(uih->font) * choice->n + 2 * BORDERHEIGHT;
+    choice->height = xtextheight(uih->image, uih->font) * choice->n + 2 * BORDERHEIGHT;
     choice->active = choice->selected;
-    choice->y = y - choice->active * xtextheight(uih->font);
+    choice->y = y - choice->active * xtextheight(uih->image, uih->font);
     dialog.mousegrab = 1;
     if (choice->x + choice->width > uih->image->width)
 	choice->x = uih->image->width - choice->width;
@@ -1155,19 +1154,19 @@ ui_closechoicemenu(struct uih_context *uih, struct ui_choicedata *choice)
 }
 
 static void
-ui_buildchoice(struct dialogitem *item, CONST menudialog * entry)
+ui_buildchoice(struct dialogitem *item, const menudialog * entry)
 {
     int i;
     struct ui_choicedata *data =
 	(struct ui_choicedata *) malloc(sizeof(*data));
     item->height = BUTTONHEIGHT;
-    item->width = xtextwidth(uih->font, item->dialog->question);
+    item->width = xtextwidth(uih->image, uih->font, item->dialog->question);
     item->width1 = 0;
     data->menu = NULL;
 
-    data->texts = (CONST char **) entry->defstr;
+    data->texts = (const char **) entry->defstr;
     for (i = 0; data->texts[i] != NULL; i++) {
-	int w = xtextwidth(uih->font, data->texts[i]);
+	int w = xtextwidth(uih->image, uih->font, data->texts[i]);
 	if (w > item->width1)
 	    item->width1 = w;
     }
@@ -1192,7 +1191,7 @@ static void ui_drawchoice(struct dialogitem *item)
 		   BUTTONHEIGHT | BORDER_LIGHT, 0);
     xprint(uih->image, uih->font, dialog.half + BORDERWIDTH,
 	   item->y + BORDERHEIGHT, data->texts[data->selected],
-	   uih->encoding, SELECTED(item) ? SELCOLOR(uih) : FGCOLOR(uih),
+	   SELECTED(item) ? SELCOLOR(uih) : FGCOLOR(uih),
 	   BGCOLOR(uih), 0);
     ui_drawquestion(item);
 }
@@ -1255,7 +1254,7 @@ ui_mousechoice(struct dialogitem *item, int x, int y, int buttons,
 	    return;
 	}
 	if ((flags & MOUSE_MOVE) && in) {
-	    in = (y - data->y) / xtextheight(uih->font);
+	    in = (y - data->y) / xtextheight(uih->image, uih->font);
 	    if (in < 0)
 		in = 0;
 	    if (in >= data->n)
@@ -1281,7 +1280,7 @@ static void ui_unselectchoice(struct dialogitem *item)
     ui_closechoicemenu(uih, data);
 }
 
-CONST static struct dialogtype choicedialog = {
+const static struct dialogtype choicedialog = {
     ui_buildchoice,
     ui_keychoice,
     ui_mousechoice,
@@ -1312,7 +1311,7 @@ static void ui_dialogdraw(struct uih_context *c, void *data)
 }
 
 #define YSKIP 2
-void ui_builddialog(CONST menuitem * item)
+void ui_builddialog(const menuitem * item)
 {
     int n = 2;
     int ypos;
@@ -1375,10 +1374,10 @@ void ui_builddialog(CONST menuitem * item)
 	    dialog.width = dialog.items[n].width;
     }
     dialog.height += YSKIP * (n - 1);
-    n = xtextwidth(uih->font, gettext("OK")) + xtextwidth(uih->font,
+    n = xtextwidth(uih->image, uih->font, gettext("OK")) + xtextwidth(uih->image, uih->font,
 							  gettext
 							  ("Cancel")) +
-	xtextwidth(uih->font, gettext("Help")) + 10;
+	xtextwidth(uih->image, uih->font, gettext("Help")) + 10;
     if (dialog.width < n)
 	dialog.width = n;
     dialog.half = dialog.width + 2 * BORDERWIDTH;
