@@ -12,7 +12,7 @@
 #ifndef BEOS_DRIVER
 /*On windows we use message boxes done in the ui_win32.c code*/
 #ifndef WIN32_DRIVER
-void x_message(CONST char *text, ...)
+void x_message(const char *text, ...)
 {
     va_list ap;
     va_start(ap, text);
@@ -21,7 +21,7 @@ void x_message(CONST char *text, ...)
     va_end(ap);
 }
 
-void x_error(CONST char *text, ...)
+void x_error(const char *text, ...)
 {
     va_list ap;
     va_start(ap, text);
@@ -30,7 +30,7 @@ void x_error(CONST char *text, ...)
     va_end(ap);
 }
 
-void x_fatalerror(CONST char *text, ...)
+void x_fatalerror(const char *text, ...)
 {
     va_list ap;
     va_start(ap, text);
